gchecky.model.promotion_t

Package gchecky :: Module model :: Class promotion_t |
[hide private]
[frames] | no frames]

# Class promotion_t

source code

    object --+
             |
     gxml.Node --+
                 |
                promotion_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| description = `String:PATH(description):OPT:EMPTY`
| id = `Long:PATH(id):REQ`
| name = `String:PATH(name):REQ:EMPTY`
| total_amount = `Node:PATH(total-amount):REQ:{ price_t }`
| _fields = ``{``'``description``'``:` String:PATH(description):OPT:EMPTY`,` `...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'description': String:PATH(description):OPT:EMPTY,
       'id': Long:PATH(id):REQ,
       'name': String:PATH(name):REQ:EMPTY,
       'total_amount': Node:PATH(total-amount):REQ:{ price_t }}